Re-exports
pub use beacon::EntropyCallbackMsg;pub use beacon::EntropyRequest;pub use beacon::CalculateFeeQuery;pub use msg::QueryMsg as BeaconQueryMsg;pub use provide::BeaconConfigQuery;pub use provide::BeaconConfigResponse;
Modules
- beacon
- Functions for interacting with the Beacon as a consumer of entropy.
- msg
- Structs describing the ExecuteMsg, QueryMsg, and InstantiateMsg of the Beacon.
- proof
- Convinience structs for representing Entropy proofs with and without the [ecvrf] feature.
- provide
- Functions for interacting with the Beacon as a provider of entropy.